@@ -8,23 +8,24 @@ use bytes;
 
 require Exporter ;
 
-use IO::Compress::RawDeflate 2.211 ();
-use IO::Compress::Adapter::Deflate 2.211 ;
+use IO::Compress::RawDeflate 2.215 ();
+use IO::Compress::Adapter::Deflate 2.215 ;
 
-use IO::Compress::Zlib::Constants 2.211 ;
-use IO::Compress::Base::Common  2.211 qw();
+use IO::Compress::Zlib::Constants 2.215 ;
+use IO::Compress::Base::Common  2.215 qw();
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, %DEFLATE_CONSTANTS, $DeflateError);
 
-$VERSION = '2.211';
+$VERSION = '2.215';
 $DeflateError = '';
 
 @ISA    = qw(IO::Compress::RawDeflate Exporter);
 @EXPORT_OK = qw( $DeflateError deflate ) ;
 %EXPORT_TAGS = %IO::Compress::RawDeflate::DEFLATE_CONSTANTS ;
 
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+$EXPORT_TAGS{all} = [ defined $EXPORT_TAGS{all} ? @{ $EXPORT_TAGS{all} } : (), @EXPORT_OK ] ;
+
 Exporter::export_ok_tags('all');
 
 
@@ -952,7 +953,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2026 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
