@@ -8,12 +8,12 @@ use bytes;
 
 require Exporter ;
 
-use IO::Compress::RawDeflate 2.211 () ;
-use IO::Compress::Adapter::Deflate 2.211 ;
+use IO::Compress::RawDeflate 2.215 () ;
+use IO::Compress::Adapter::Deflate 2.215 ;
 
-use IO::Compress::Base::Common  2.211 qw(:Status );
-use IO::Compress::Gzip::Constants 2.211 ;
-use IO::Compress::Zlib::Extra 2.211 ;
+use IO::Compress::Base::Common  2.215 qw(:Status );
+use IO::Compress::Gzip::Constants 2.215 ;
+use IO::Compress::Zlib::Extra 2.215 ;
 
 BEGIN
 {
@@ -25,14 +25,14 @@ BEGIN
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, %DEFLATE_CONSTANTS, $GzipError);
 
-$VERSION = '2.211';
+$VERSION = '2.215';
 $GzipError = '' ;
 
 @ISA    = qw(IO::Compress::RawDeflate Exporter);
 @EXPORT_OK = qw( $GzipError gzip ) ;
 %EXPORT_TAGS = %IO::Compress::RawDeflate::DEFLATE_CONSTANTS ;
 
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+$EXPORT_TAGS{all} = [ defined $EXPORT_TAGS{all} ? @{ $EXPORT_TAGS{all} } : (), @EXPORT_OK ] ;
 Exporter::export_ok_tags('all');
 
 sub new
@@ -1327,7 +1327,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2026 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
