@@ -4,41 +4,41 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.211 qw(:Status );
-use IO::Compress::RawDeflate 2.211 ();
-use IO::Compress::Adapter::Deflate 2.211 ;
-use IO::Compress::Adapter::Identity 2.211 ;
-use IO::Compress::Zlib::Extra 2.211 ;
-use IO::Compress::Zip::Constants 2.211 ;
+use IO::Compress::Base::Common  2.215 qw(:Status );
+use IO::Compress::RawDeflate 2.215 ();
+use IO::Compress::Adapter::Deflate 2.215 ;
+use IO::Compress::Adapter::Identity 2.215 ;
+use IO::Compress::Zlib::Extra 2.215 ;
+use IO::Compress::Zip::Constants 2.215 ;
 
 use File::Spec();
 use Config;
 
-use Compress::Raw::Zlib  2.211 ();
+use Compress::Raw::Zlib  2.214 ();
 
 BEGIN
 {
     eval { require IO::Compress::Adapter::Bzip2 ;
-           IO::Compress::Adapter::Bzip2->VERSION( 2.211 );
+           IO::Compress::Adapter::Bzip2->VERSION( 2.215 );
            require IO::Compress::Bzip2 ;
-           IO::Compress::Bzip2->VERSION( 2.211 );
+           IO::Compress::Bzip2->VERSION( 2.215 );
          } ;
 
     eval { require IO::Compress::Adapter::Lzma ;
-           IO::Compress::Adapter::Lzma->VERSION( 2.211 );
+           IO::Compress::Adapter::Lzma->VERSION( 2.214 );
            require IO::Compress::Lzma ;
-           IO::Compress::Lzma->VERSION( 2.211 );
+           IO::Compress::Lzma->VERSION( 2.214 );
          } ;
 
     eval { require IO::Compress::Adapter::Xz ;
-           IO::Compress::Adapter::Xz->VERSION( 2.211 );
+           IO::Compress::Adapter::Xz->VERSION( 2.214 );
            require IO::Compress::Xz ;
-           IO::Compress::Xz->VERSION( 2.211 );
+           IO::Compress::Xz->VERSION( 2.214 );
          } ;
     eval { require IO::Compress::Adapter::Zstd ;
-           IO::Compress::Adapter::Zstd->VERSION( 2.211 );
+           IO::Compress::Adapter::Zstd->VERSION( 2.214 );
            require IO::Compress::Zstd ;
-           IO::Compress::Zstd->VERSION( 2.211 );
+           IO::Compress::Zstd->VERSION( 2.214 );
          } ;
 }
 
@@ -47,14 +47,14 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, %DEFLATE_CONSTANTS, $ZipError);
 
-$VERSION = '2.211';
+$VERSION = '2.215';
 $ZipError = '';
 
 @ISA = qw(IO::Compress::RawDeflate Exporter);
 @EXPORT_OK = qw( $ZipError zip ) ;
 %EXPORT_TAGS = %IO::Compress::RawDeflate::DEFLATE_CONSTANTS ;
 
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+$EXPORT_TAGS{all} = [ defined $EXPORT_TAGS{all} ? @{ $EXPORT_TAGS{all} } : (), @EXPORT_OK ] ;
 
 $EXPORT_TAGS{zip_method} = [qw( ZIP_CM_STORE ZIP_CM_DEFLATE ZIP_CM_BZIP2 ZIP_CM_LZMA ZIP_CM_XZ ZIP_CM_ZSTD)];
 push @{ $EXPORT_TAGS{all} }, @{ $EXPORT_TAGS{zip_method} };
@@ -2285,7 +2285,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2026 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
