@@ -4,22 +4,22 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.211 ();
+use IO::Compress::Base::Common 2.215 ();
 
-use IO::Uncompress::Base 2.211 ;
+use IO::Uncompress::Base 2.215 ;
 
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyUncompressError);
 
-$VERSION = '2.211';
+$VERSION = '2.215';
 $AnyUncompressError = '';
 
 @ISA = qw(IO::Uncompress::Base Exporter);
 @EXPORT_OK = qw( $AnyUncompressError anyuncompress ) ;
 %EXPORT_TAGS = %IO::Uncompress::Base::DEFLATE_CONSTANTS if keys %IO::Uncompress::Base::DEFLATE_CONSTANTS;
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+$EXPORT_TAGS{all} = [ defined $EXPORT_TAGS{all} ? @{ $EXPORT_TAGS{all} } : (), @EXPORT_OK ] ;
 Exporter::export_ok_tags('all');
 
 # TODO - allow the user to pick a set of the three formats to allow
@@ -33,26 +33,26 @@ BEGIN
    # Don't trigger any __DIE__ Hooks.
    local $SIG{__DIE__};
 
-   eval ' use IO::Uncompress::Adapter::Inflate 2.211 ;';
-   eval ' use IO::Uncompress::Adapter::Bunzip2 2.211 ;';
-   eval ' use IO::Uncompress::Adapter::LZO 2.211 ;';
-   eval ' use IO::Uncompress::Adapter::Lzf 2.211 ;';
-   eval ' use IO::Uncompress::Adapter::UnLzma 2.211 ;';
-   eval ' use IO::Uncompress::Adapter::UnXz 2.211 ;';
-   eval ' use IO::Uncompress::Adapter::UnZstd 2.211 ;';
-   eval ' use IO::Uncompress::Adapter::UnLzip 2.211 ;';
+   eval ' use IO::Uncompress::Adapter::Inflate 2.215 ;';
+   eval ' use IO::Uncompress::Adapter::Bunzip2 2.215 ;';
+   eval ' use IO::Uncompress::Adapter::LZO 2.214 ;';
+   eval ' use IO::Uncompress::Adapter::Lzf 2.214 ;';
+   eval ' use IO::Uncompress::Adapter::UnLzma 2.214 ;';
+   eval ' use IO::Uncompress::Adapter::UnXz 2.214 ;';
+   eval ' use IO::Uncompress::Adapter::UnZstd 2.214 ;';
+   eval ' use IO::Uncompress::Adapter::UnLzip 2.214 ;';
 
-   eval ' use IO::Uncompress::Bunzip2 2.211 ;';
-   eval ' use IO::Uncompress::UnLzop 2.211 ;';
-   eval ' use IO::Uncompress::Gunzip 2.211 ;';
-   eval ' use IO::Uncompress::Inflate 2.211 ;';
-   eval ' use IO::Uncompress::RawInflate 2.211 ;';
-   eval ' use IO::Uncompress::Unzip 2.211 ;';
-   eval ' use IO::Uncompress::UnLzf 2.211 ;';
-   eval ' use IO::Uncompress::UnLzma 2.211 ;';
-   eval ' use IO::Uncompress::UnXz 2.211 ;';
-   eval ' use IO::Uncompress::UnZstd 2.211 ;';
-   eval ' use IO::Uncompress::UnLzip 2.211 ;';
+   eval ' use IO::Uncompress::Bunzip2 2.215 ;';
+   eval ' use IO::Uncompress::UnLzop 2.214 ;';
+   eval ' use IO::Uncompress::Gunzip 2.215 ;';
+   eval ' use IO::Uncompress::Inflate 2.215 ;';
+   eval ' use IO::Uncompress::RawInflate 2.215 ;';
+   eval ' use IO::Uncompress::Unzip 2.215 ;';
+   eval ' use IO::Uncompress::UnLzf 2.214 ;';
+   eval ' use IO::Uncompress::UnLzma 2.214 ;';
+   eval ' use IO::Uncompress::UnXz 2.214 ;';
+   eval ' use IO::Uncompress::UnZstd 2.214 ;';
+   eval ' use IO::Uncompress::UnLzip 2.214 ;';
 
 }
 
@@ -1090,7 +1090,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2026 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
