@@ -5,23 +5,23 @@ use strict ;
 use warnings;
 use bytes;
 
-use Compress::Raw::Zlib  2.211 ;
-use IO::Compress::Base::Common  2.211 qw(:Status );
+use Compress::Raw::Zlib  2.214 ;
+use IO::Compress::Base::Common  2.215 qw(:Status );
 
-use IO::Uncompress::Base  2.211 ;
-use IO::Uncompress::Adapter::Inflate  2.211 ;
+use IO::Uncompress::Base  2.215 ;
+use IO::Uncompress::Adapter::Inflate  2.215 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, %DEFLATE_CONSTANTS, $RawInflateError);
 
-$VERSION = '2.211';
+$VERSION = '2.215';
 $RawInflateError = '';
 
 @ISA    = qw(IO::Uncompress::Base Exporter);
 @EXPORT_OK = qw( $RawInflateError rawinflate ) ;
 %DEFLATE_CONSTANTS = ();
 %EXPORT_TAGS = %IO::Uncompress::Base::EXPORT_TAGS ;
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+$EXPORT_TAGS{all} = [ defined $EXPORT_TAGS{all} ? @{ $EXPORT_TAGS{all} } : (), @EXPORT_OK ] ;
 Exporter::export_ok_tags('all');
 
 #{
@@ -1138,7 +1138,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2026 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
