@@ -9,14 +9,14 @@ use warnings;
 use bytes;
 
 use IO::File;
-use IO::Uncompress::RawInflate  2.211 ;
-use IO::Compress::Base::Common  2.211 qw(:Status );
-use IO::Uncompress::Adapter::Inflate  2.211 ;
-use IO::Uncompress::Adapter::Identity 2.211 ;
-use IO::Compress::Zlib::Extra 2.211 ;
-use IO::Compress::Zip::Constants 2.211 ;
+use IO::Uncompress::RawInflate  2.215 ;
+use IO::Compress::Base::Common  2.215 qw(:Status );
+use IO::Uncompress::Adapter::Inflate  2.215 ;
+use IO::Uncompress::Adapter::Identity 2.215 ;
+use IO::Compress::Zlib::Extra 2.215 ;
+use IO::Compress::Zip::Constants 2.215 ;
 
-use Compress::Raw::Zlib  2.211 () ;
+use Compress::Raw::Zlib  2.214 () ;
 
 BEGIN
 {
@@ -24,13 +24,13 @@ BEGIN
    local $SIG{__DIE__};
 
     eval{ require IO::Uncompress::Adapter::Bunzip2 ;
-          IO::Uncompress::Adapter::Bunzip2->VERSION(2.211) } ;
+          IO::Uncompress::Adapter::Bunzip2->VERSION(2.215) } ;
     eval{ require IO::Uncompress::Adapter::UnLzma ;
-          IO::Uncompress::Adapter::UnLzma->VERSION(2.211) } ;
+          IO::Uncompress::Adapter::UnLzma->VERSION(2.214) } ;
     eval{ require IO::Uncompress::Adapter::UnXz ;
-          IO::Uncompress::Adapter::UnXz->VERSION(2.211) } ;
+          IO::Uncompress::Adapter::UnXz->VERSION(2.214) } ;
     eval{ require IO::Uncompress::Adapter::UnZstd ;
-          IO::Uncompress::Adapter::UnZstd->VERSION(2.211) } ;
+          IO::Uncompress::Adapter::UnZstd->VERSION(2.214) } ;
 }
 
 
@@ -38,13 +38,13 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnzipError, %headerLookup);
 
-$VERSION = '2.211';
+$VERSION = '2.215';
 $UnzipError = '';
 
 @ISA    = qw(IO::Uncompress::RawInflate Exporter);
 @EXPORT_OK = qw($UnzipError unzip );
 %EXPORT_TAGS = %IO::Uncompress::RawInflate::EXPORT_TAGS ;
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+$EXPORT_TAGS{all} = [ defined $EXPORT_TAGS{all} ? @{ $EXPORT_TAGS{all} } : (), @EXPORT_OK ] ;
 Exporter::export_ok_tags('all');
 
 %headerLookup = (
@@ -802,7 +802,14 @@ sub filterUncompressed
 # from Archive::Zip & info-zip
 sub _dosToUnixTime
 {
+    # Returns zero when $dt is already zero or it doesn't expand to a value that Time::Local::timelocal()
+    # can handle.
+
 	my $dt = shift;
+    # warn "_dosToUnixTime dt=[$dt]\n";
+
+    # some zip files don't populate the datetime field at all
+    return 0 if ! $dt;
 
 	my $year = ( ( $dt >> 25 ) & 0x7f ) + 80;
 	my $mon  = ( ( $dt >> 21 ) & 0x0f ) - 1;
@@ -813,10 +820,15 @@ sub _dosToUnixTime
 	my $sec  = ( ( $dt << 1 ) & 0x3e );
 
     use Time::Local ;
-    my $time_t = Time::Local::timelocal( $sec, $min, $hour, $mday, $mon, $year);
+
+    my $time_t ;
+    # wrap in an eval to catch out of range errors
+    eval {
+        $time_t = Time::Local::timelocal( $sec, $min, $hour, $mday, $mon, $year);
+    } ;
+
     return 0 if ! defined $time_t;
     return $time_t;
-
 }
 
 #sub scanCentralDirectory
@@ -2012,7 +2024,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2026 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
